function loadGalleries() {
    document.querySelectorAll('.gallery').forEach(gallery => {
        var photos = [], dialog
        gallery.querySelectorAll(".photo").forEach(img => {
            const src = img.src.replace('_thumbnail', '_display')
            let photo = {
                src: src,
                caption: img.dataset.caption,
                orig: img.dataset.orig
            }
            photos.push(photo)
            img.parentElement.addEventListener("click", event => {
                event.preventDefault()
                event.stopPropagation()
                dialog.open(src)
            })
        })
        dialog = loadGallery(photos)
        gallery.appendChild(dialog.element)
    })
}

function loadGallery(images) {
    var gallery = document.createElement("dialog")
    gallery.classList.add("gallery-dialog")
    gallery.innerHTML = `
        <div class="photo-container">
            <div class="image">
                <img class="main-image" src="" alt="">
            </div>
            <button class="prev nav-btn">❮ Prev</button>
            <button class="next nav-btn">Next ❯</button>
        </div>
        <button class="close">&#10006;</button>
        <a class="download disabled" target="_blank" download title="download original">
            <svg xmlns="http://www.w3.org/2000/svg" width="14" height="14" viewBox="0 0 304 384"><path fill="currentColor" d="M299 128L149 277L0 128h85V0h128v128h86zM0 320h299v43H0v-43z"/></svg>
        </a>
        <div class="caption"></div>
        <div class="thumbnails"></div>
    `

    gallery.addEventListener("click", event => {
        if (event.target.className == "close") {
            gallery.close();
            return
        }
        var rect = gallery.getBoundingClientRect();
        var isInDialog = (rect.top <= event.clientY && event.clientY <= rect.top + rect.height &&
            rect.left <= event.clientX && event.clientX <= rect.left + rect.width);
        if (!isInDialog) {
            gallery.close();
        }
    })
    let currentIndex = 0;

    const mainImage = gallery.querySelector(".main-image");
    const caption = gallery.querySelector(".caption");
    const prevBtn = gallery.querySelector(".prev.nav-btn");
    const nextBtn = gallery.querySelector(".next.nav-btn");
    const thumbnailsContainer = gallery.querySelector(".thumbnails");
    const download = gallery.querySelector(".download");

    function updateSlideshow(index) {
        mainImage.src = images[index].src.replace('_display', '_thumbnail');
        setTimeout(() => {
            mainImage.src = images[index].src;
        }, 0)
        caption.innerHTML = images[index].caption;
        gallery.querySelectorAll(".thumbnail").forEach((thumb, i) => {
            thumb.classList.toggle("active", i === index);
        });
        if (images[index].orig) {
            download.href = images[index].orig
            download.classList.remove('disabled')
        } else {
            download.href = ""
            download.classList.add('disabled')
        }
        prevBtn.disabled = index === 0;
        nextBtn.disabled = index === images.length - 1;
    }

    function createThumbnails() {
        images.forEach((img, index) => {
            const thumb = document.createElement("img");
            thumb.src = img.src.replace('_display', '_thumbnail');
            thumb.classList.add("thumbnail");
            thumb.onclick = () => {
                currentIndex = index;
                updateSlideshow(index);
            };
            thumbnailsContainer.appendChild(thumb);
        });
    }

    function showSlideshow() {
        window.dialog = gallery
        gallery.showModal()
    }

    prevBtn.onclick = () => {
        if (currentIndex > 0) {
            currentIndex--;
            updateSlideshow(currentIndex);
        }
    };

    nextBtn.onclick = () => {
        if (currentIndex < images.length - 1) {
            currentIndex++;
            updateSlideshow(currentIndex);
        }
    };

    createThumbnails();
    updateSlideshow(currentIndex);

    const imagesIndex = images.map(img => img.src);
    return {
        element: gallery,
        open: function(src) {
            currentIndex = imagesIndex.indexOf(src)
            updateSlideshow(currentIndex)
            showSlideshow()
        }
    }
}
window.addEventListener("load", loadGalleries)


